/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DirectoryBean.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.directory;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.ejb.EJB;
import javax.ejb.Remote;
import javax.ejb.Stateful;


/**
 * Directory stateful bean implementation.
 * @author Julien Blais
 */
@Stateful(mappedName = "ejb/DirectoryBean")
@Remote(DirectoryRemote.class)
public class DirectoryBean implements DirectoryRemote, Serializable {
    /**
     * Id for Serializable class.
     */
    private static final long serialVersionUID = 237823455784790L;

    /**
     * Ejb stateful used to manage the persistant directory.
     */
    @EJB(beanName = "DirectoryManagerBean")
    private DirectoryManagerLocal dmEjb = null;

    /**
     * Empty constructor.
     */
    public DirectoryBean() {
    }

    public boolean create(final String userName, final String passwd) {
        System.out.println("List of directory users :");
        for (Sessions s : dmEjb.getListSessions()) {
            System.out.println(s.getUsername());
        }

        Sessions ses = getSession(userName);
        Directorys dir = null;
        boolean found = false, created = false;
        if (ses == null) {
            System.out.println("New Session Creation ...");
            ses = new Sessions(userName, passwd);
            dmEjb.addNewSession(ses);
            created = true;
        } else {
            System.out.println("Use Session " + userName);
            List<Directorys> ldir = dmEjb.getListDir();
            Iterator<Directorys> itdir = ldir.iterator();
            while (!found && itdir.hasNext()) {
                dir = itdir.next();
                if (dir.getIdSession().getUsername().equals(ses.getUsername())) {
                    System.out.println(userName + "'Directory found ...");
                    found = true;
                    dmEjb.setDir(dir);
                }
            }
        }
        if (!found) {
            dir = new Directorys();
            dir.setEltDirOfCollection(null);
            dir.setIdSession(ses);
            dmEjb.addNewDirectory(dir);
            dmEjb.setDir(dir);
        }
        return created;
    }

    public boolean connect(final String userName, final String passwd) {
        Sessions ses = getSession(userName);
        Directorys dir = null;
        boolean connected = false;
        if (!(ses == null) && ses.getPasswd().equals(passwd)) {
            dir = getDirectory(ses);
            dmEjb.setDir(dir);
            connected = true;
        }
        return connected;
    }

    public ArrayList<Person> getList() {
        return dmEjb.getList();
    }

    public void add(final String firstName, final String lastName, final String adress, final String phone) {
        dmEjb.add(firstName, lastName, adress, phone);
    }

    public void remove(final String firstName, final String phone) {
        dmEjb.remove(firstName, phone);
    }

    public String getPhoneNumber(final String firstName, final String lastName) throws Exception {
        return dmEjb.getPhoneNumber(firstName, lastName);
    }

    /**
     * Get a user session.
     * @param userName the user name of the session to get
     * @return the session of the user or null if this session doesn't exist
     */
    private Sessions getSession(final String userName) {
        List<Sessions> lses = dmEjb.getListSessions();
        Sessions ses = null;

        for (Sessions s : lses) {
            if (s.getUsername().equals(userName)) {
                ses = s;
                break;
            }
        }

        return ses;
    }

    /**
     * Gets the directory of the user.
     * @param ses the session user accessing the directory
     * @return the directory used by the connected user
     */
    public Directorys getDirectory(final Sessions ses) {
        Directorys res = null;
        List<Directorys> rl = dmEjb.getListDir();

        for (Directorys d : rl) {
            if (d.getIdSession().equals(ses)) {
                res = d;
            }
        }

        return res;
    }
}
